@@ -10,7 +10,7 @@ class Config(object):
         self._context = {}
         self._context['name'] = name
         self._context['args'] = args
-        self._context['name_value_pairs'] = kw
+        self._context['kw'] = kw
     def __setitem__(self, name, value):
         self._context[name] = value
     def __getitem__(self, name):
@@ -43,6 +43,10 @@ class StoreConfigParser(object):
                     amqp = amqp"""
                 configs = dict(self._c.items(block))
                 s = Config(block[len('store_'):], **configs)
+                if "views" in configs and configs["views"] in self._c.sections():
+                    # Copy across amqp settings
+                    views = Config(configs["views"], **dict(self._c.items(configs["views"])))
+                    s['views'] = views
                 if "amqp" in configs and configs["amqp"] in self._c.sections():
                     # Copy across amqp settings
                     amqp = Config(configs["amqp"], **dict(self._c.items(configs["amqp"])))
